#
# db2_secured::validators::disable_grants_during_restore
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `DB2_RESTORE_GRANT_ADMIN_AUTHORITIES` registry variable determines whether the authorization ID of the user performing a restore is granted administrative authorities (`SECADM`, `DBADM`, `DATAACCESS`, and `ACCESSCTRL` authorities) on the restored database. It is typically used when restoring a database on a server where the original database creator account does not exist. It is recommended that this variable not be set except when specifically performing a restore where you wish these privileges to be granted so they are not accidentally granted.
# 
# 
# ## Rationale
# 
# Use of this registry variable may grant administrative authorities accidentally if the value is left on during normal operations and a restore is run.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::disable_grants_during_restore: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `disable_grants_during_restore` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::disable_grants_during_restore (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "disable_grants_during_restore validation on ${title}":
      ensure => 'present',
    }
    -> validation { "grants during restore should be DISABLED on ${title}":
      check           => 'db2set -all | grep DB2_RESTORE_GRANT_ADMIN_AUTHORITIES',
      path            => ['/bin', "${home}/sqllib/adm"],
      environment     => "DB2INSTANCE=${instance}",
      expected_output => /(?-mix:(^$|DB2_RESTORE_GRANT_ADMIN_AUTHORITIES=OFF$))/,
      user            => $instance,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "grants during restore are NOT DISABLED on ${instance}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
