#
# db2_secured::validators::limit_os_privileges_of_fenced_mode_process
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `DB2_LIMIT_FENCED_GROUP` registry variable allows restricting the operating system privileges of the fenced mode process (db2fmp) to the privileges assigned to the `DB2USERS` group.
# This variable only has effect if extended security is enabled (`DB2_EXTSEC`) and the Db2 Service Account is not LocalSystem.
# This registry variable only applies to Db2 Servers running on Windows.
# 
# 
# ## Rationale
# 
# By default, the fenced mode process has access to both the DB2ADMNS and DB2USERS groups.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::limit_os_privileges_of_fenced_mode_process: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `limit_os_privileges_of_fenced_mode_process` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::limit_os_privileges_of_fenced_mode_process (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "limit_os_privileges_of_fenced_mode_process validation on ${title}":
      ensure => 'present',
    }
    -> validation { "OS privileges of fenced mode process should be LIMITED on ${title}":
      check           => 'db2set -all | grep DB2_LIMIT_FENCED_GROUP',
      path            => ['/bin', "${home}/sqllib/adm"],
      environment     => "DB2INSTANCE=${instance}",
      expected_output => /(?-mix:\[i\] DB2_LIMIT_FENCED_GROUP=ON$)/,
      user            => $instance,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "OS privileges of fenced mode process are NOT LIMITED on ${title}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
