#
# db2_secured::validators::remove_default_databases
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A DB2 instance may come installed with default databases. It is recommended that the `SAMPLE` database be removed.
# 
# 
# ## Rationale
# 
# Removing unused, well-known databases will reduce the attack surface of the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::remove_default_databases: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `remove_default_databases` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::remove_default_databases (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "remove_default_databases validation on ${title}":
      ensure => 'present',
    }
    -> validation { "default databases should be REMOVED on ${title}":
      check           => 'db2 list database directory | grep "Database name *= SAMPLE" || echo TRUE',
      path            => ['/bin', "${home}/sqllib/bin"],
      environment     => "DB2INSTANCE=${instance}",
      expected_output => /(?-mix:^TRUE$)/,
      user            => $instance,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "default databases are NOT REMOVED on ${title}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
