#
# db2_secured::validators::require_explicit_authorization_for_cataloging
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# DB2 can be configured to allow users that do not possess the `SYSADM` authority to catalog and uncatalog databases and nodes. It is recommended that the `catalog_noauth` parameter be set to `NO`.
# 
# 
# ## Rationale
# 
# Cataloging a database is the process of registering a database from a remote client to allow remote call and access. Setting `catalog_noauth` to `YES` bypasses all permissions checks and allows anyone to catalog and uncatalog databases.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::require_explicit_authorization_for_cataloging: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `require_explicit_authorization_for_cataloging` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.3
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::require_explicit_authorization_for_cataloging (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "require_explicit_authorization_for_cataloging validation on ${title}":
      ensure => 'present',
    }
    -> validation { "explicit authorization for cataloging should be REQUIRED on instance ${instance}":
      check           => 'db2 get database manager configuration',
      path            => ['/bin', "${home}/sqllib/bin"],
      environment     => "DB2INSTANCE=${instance}",
      expected_output => /(?-mix:^ Cataloging allowed without authority *\(CATALOG_NOAUTH\) = NO$)/,
      user            => $instance,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "explicit authorization for cataloging is NOT REQUIRED on instance ${instance}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
