#
# db2_secured::validators::restrict_access_to_syscat_eventtables
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `SYSCAT.EVENTTABLES` view contains the name of the destination table that will receive the monitoring events. It is recommended that the `PUBLIC` role be restricted from accessing this view.
# 
# 
# ## Rationale
# 
# `PUBLIC` should not have access to see the target name of the event monitoring table.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::restrict_access_to_syscat_eventtables: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `restrict_access_to_syscat_eventtables` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 6.6
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.2.13
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::restrict_access_to_syscat_eventtables (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  $query    = @(QUERY)
      SELECT GRANTEE
        FROM SYSCAT.TABAUTH
       WHERE TABSCHEMA = 'SYSCAT'
         AND TABNAME = 'EVENTTABLES'
         AND GRANTEE = 'PUBLIC'
    |-QUERY

  db2_secured_setup { "restrict_access_to_syscat_eventtables validation on ${title}":
    ensure => 'present',
  }
  -> db2_validation { "access to SYSCAT.EVENTTABLES should be RESTRICTED on ${title}":
    check                   => $query,
    instance_name           => $inst,
    database_name           => $db,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "access to SYSCAT.EVENTTABLES is NOT RESTRICTED on ${title}",
  }
}
