#
# db2_secured::validators::review_role_grantees_with_with_admin_option
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Using the `WITH ADMIN OPTION` clause of the `GRANT` (Role) SQL statement, the security administrator can delegate the management and control of membership in a role to someone else.
# 
# 
# ## Rationale
# 
# The `WITH ADMIN OPTION` clause gives another user the authority to grant membership in the role to other users, to revoke membership in the role from other members of the role, and to comment on a role, but not to drop the role.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::review_role_grantees_with_with_admin_option: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `review_role_grantees_with_with_admin_option` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 8.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::review_role_grantees_with_with_admin_option (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  $query    = @(QUERY)
      SELECT ROLENAME
           , GRANTEE
           , ADMIN
        FROM SYSCAT.ROLEAUTH
       WHERE GRANTORTYPE <> 'S'
         AND ADMIN = 'Y'
    |-QUERY

  db2_secured_setup { "review_role_grantees_with_with_admin_option validation on ${title}":
    ensure => 'present',
  }
  -> db2_validation { "Role grantees with WITH ADMIN OPTION should be REVIEVED on ${title}":
    check                   => $query,
    instance_name           => $inst,
    database_name           => $db,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "REVIEW Role grantees with WITH ADMIN OPTION on ${title}",
  }
}
