#
# db2_secured::validators::review_system_tablespaces
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# System tablespaces store all system object data within that database. It is recommended that system tablespaces are used to stored system data only and not user data.
# 
# 
# ## Rationale
# 
# Users should not have privileges to create user data objects within the system tablespaces. User data objects created within the system tablespaces should be removed.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::review_system_tablespaces: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `review_system_tablespaces` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.3
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.5.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::review_system_tablespaces (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  $query    = @(QUERY)
      SELECT TABSCHEMA
           , TABNAME
           , TBSPACE
        FROM SYSCAT.TABLES
       WHERE TABSCHEMA NOT IN ( 'ADMINISTRATOR'
                              , 'SYSIBM'
                              , 'SYSTOOLS')
         AND TBSPACE IN ( 'SYSCATSPACE'
                        , 'SYSTOOLSPACE'
                        , 'SYSTOOLSTMPSPACE'
                        , 'TEMPSPACE')
    |-QUERY

  db2_secured_setup { "review_system_tablespaces validation on ${title}":
    ensure => 'present',
  }
  -> db2_validation { "NON-SYSTEM tables shouldn't be stored in SYSTEM tablespaces on ${title}":
    check                   => $query,
    instance_name           => $inst,
    database_name           => $db,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "NON-SYSTEM tables FOUND in SYSTEM tablespaces on ${title}",
  }
}
