#
# db2_secured::validators::secure_accessctrl_authority
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# `ACCESSCTRL` authority is the authority required to grant and revoke privileges on objects within a specific database. Some of these privileges include `BINDADD`, `CONNECT`, `CREATETAB`, `CREATE_EXTERNAL_ROUTINE`, `LOAD`, and `QUIESCE_CONNECT`. It has no inherent privilege to access data stored in tables, except the catalog tables and views.
# The `ACCESSCTRL` authority cannot be granted to `PUBLIC`.
# 
# 
# ## Rationale
# 
# The `ACCESSCTRL` authority gives the grantee access control to a specified database. With this authority, the grantee can grant/revoke privileges to other users. `ACCESSCTRL` can be granted to users, groups, or roles, but not `PUBLIC`. `ACCESSCTRL` authority can only be granted by the `SECADM` authority.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_accessctrl_authority: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_accessctrl_authority` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 7.9
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_accessctrl_authority (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  $query    = @(QUERY)
      SELECT DISTINCT GRANTEE
           , GRANTEETYPE
        FROM SYSCAT.DBAUTH
       WHERE ACCESSCTRLAUTH = 'Y'
    |-QUERY

  db2_secured_setup { "secure_accessctrl_authority validation on ${title}":
    ensure => 'present',
  }
  -> db2_validation { "ACCESSCTRL authority should be SECURED on ${title}":
    check                   => $query,
    instance_name           => $inst,
    database_name           => $db,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "ACCESSCTRL authority is NOT SECURED on ${title}",
  }
}
