#
# db2_secured::validators::secure_permissions_for_all_diagnostic_logs
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `diagpath` parameter specifies the location of the diagnostic files for the DB2 instance. The directory at this location should be secured so that users have read and execute privileges only (no write privileges). All DB2 administrators should have full access to the directory.
# 
# 
# ## Rationale
# 
# Securing the directory will ensure that the confidentiality, integrity, and availability of the diagnostic files contained in the directory are preserved.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_permissions_for_all_diagnostic_logs: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_permissions_for_all_diagnostic_logs` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.7
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_permissions_for_all_diagnostic_logs (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = $title.split('/')
  $instance = $elements[0]

  if $facts['db2_instances'] {
    $diag_path = $facts['db2_instances'][$instance]['diagpath'].split(' ')[0]

    db2_secured_setup { "secure_permissions_for_all_diagnostic_logs validation on ${title}":
      ensure => 'present',
    }
    -> validation { "permissions for all diagnostic logs should be SECURED on ${instance}":
      check           => "find ${diag_path}/* -not -perm 755",
      path            => '/bin',
      expected_output => /^$/,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "permissions for all diagnostic logs are NOT SECURED on ${instance}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
