#
# db2_secured::validators::secure_permissions_for_the_log_mirror_location
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `mirrorlogpath` parameter specifies the type of media and the location used to store the mirror copy of the logs. It is recommended that the directory used for the mirror copy of the logs be set to full access for DB2 administrator accounts and read and execute only for all other accounts.
# 
# 
# ## Rationale
# 
# A mirror log path should not be empty and it should be a valid path. The mirror log path stores a second copy of the active log files. Access to the directory pointed to by that path should be restricted through permissions to help ensure that the confidentiality, integrity, and availability of the mirror logs are protected.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_permissions_for_the_log_mirror_location: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_permissions_for_the_log_mirror_location` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.20
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.8
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_permissions_for_the_log_mirror_location (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  if $facts['db2_databases'] {
    $mirrorlogpath = dig($facts['db2_databases'], $title, 'mirrorlogpath')

    if $mirrorlogpath {
      db2_secured_setup { "secure_permissions_for_the_log_mirror_location validation on ${title}":
        ensure => 'present',
      }
      -> validation { "permissions for the log mirror location should be SECURE on ${title}":
        check           => "find ${mirrorlogpath}/* -not -perm 755",
        path            => '/bin',
        expected_output => /^$/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "permissions for the log mirror location are NOT SECURE on ${title}",
      }
    } else {
      warning 'log mirror location (mirrorlogpath) not set'
    }
  } else {
    warning "Skipping this validator until 'db2_databases' fact is filled"
  }
}
