#
# db2_secured::validators::secure_permissions_for_the_tertiary_archive_log_location
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `failarchpath` parameter specifies the type of media and the location used as the tertiary destination of archived logs. It is recommended that the directory used for the archived logs be set to full access for DB2 administrator accounts and read and execute only for all other accounts.
# 
# 
# ## Rationale
# 
# Restricting access to the contents of the tertiary archive log directory will help ensure that the confidentiality, integrity, and availability of archive logs are protected.
# Although there are many ways to ensure that your logs will be archived, we recommend using the value of DISK as part of the `failarchpath` parameter. This will properly ensure that the logs are archived. A finding of `OFF` is not acceptable.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_permissions_for_the_tertiary_archive_log_location: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_permissions_for_the_tertiary_archive_log_location` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.19
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.7
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_permissions_for_the_tertiary_archive_log_location (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  if $facts['db2_databases'] {
    $failarchpath = dig($facts['db2_databases'], $title, 'failarchpath')

    if $failarchpath {
      db2_secured_setup { "secure_permissions_for_the_tertiary_archive_log_location validation on ${title}":
        ensure => 'present',
      }
      -> validation { "permissions for tertiary log archive location should be SECURED on ${instance}":
        check           => "find ${failarchpath}/* -not -perm 755",
        path            => '/bin',
        expected_output => /^$/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "permissions for tertiary log archive location are NOT SECURED on ${instance}",
      }
    } else {
      warning 'tertiary log archive location (failarchpath) not set'
    }
  } else {
    warning "Skipping this validator until 'db2_databases' fact is filled"
  }
}
