#
# db2_secured::validators::secure_secadm_authority
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `SECADM` (security administrator) role grants the authority to create, alter (where applicable), and drop roles, trusted contexts, audit policies, security label components, security policies and security labels. It is also the authority required to grant and revoke roles, security labels and exemptions, and the `SETSESSIONUSER` privilege. `SECADM` authority has no inherent privilege to access data stored in tables. It is recommended that the `SECADM` role be granted to authorized users only.
# 
# 
# ## Rationale
# 
# If an account that possesses this authority is compromised or used in a malicious manner, the confidentiality, integrity, and availability of data in the DB2 instance will be at increased risk.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_secadm_authority: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_secadm_authority` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 7.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_secadm_authority (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  $query    = @(QUERY)
      SELECT DISTINCT GRANTEE
           , GRANTEETYPE
        FROM SYSCAT.DBAUTH
       WHERE SECURITYADMAUTH = 'Y'
    |-QUERY

  db2_secured_setup { "secure_secadm_authority validation on ${title}":
    ensure => 'present',
  }
  -> db2_validation { "SECADM authority should be SECURED on ${title}":
    check                   => $query,
    instance_name           => $inst,
    database_name           => $db,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "SECADM authority is NOT SECURED on ${title}",
  }
}
