#
# db2_secured::validators::secure_the_communication_buffer_exit_library
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A communication exit library is a dynamically loaded library that vendor applications use to examine communication buffers. The `comm_exit_list` parameter specifies the list of communication buffer exist libraries. The permissions on the libraries should be secured so that users other than the instance owner do not have write privileges.
# 
# 
# ## Rationale
# 
# If a malicious user has write access to a communication exit library, they can overwrite it with their own thereby receiving all of the communication buffers that Db2 receives over the network. Securing the libraries will prevent a loss of confidentiality of data.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_the_communication_buffer_exit_library: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_the_communication_buffer_exit_library` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.13
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_the_communication_buffer_exit_library (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = $title.split('/')
  $instance = $elements[0]

  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "secure_the_communication_buffer_exit_library validation on ${title}":
      ensure => 'present',
    }
    -> validation { "permissions for the communication buffer exit library should be SECURED on ${instance}":
      check           => "find ${home}/sqllib/security*/plugin/commexit -not -perm 755 2>/dev/null",
      path            => '/bin',
      expected_output => /^$/,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "permissions for the communication buffer exit library are NOT SECURED on ${instance}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
