#
# db2_secured::validators::secure_the_configuration_file
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A configuration file, ekeystore.cfg, is created by the user in order to configure external keymanager functionality.
# This file should be secured against tampering via OS permissions.
# 
# 
# ## Rationale
# 
# Set this file to be readable and writeable by only the Db2 instance owner. If this file is not secured, an attacker may delete it, causing potential interruption of operations.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_the_configuration_file: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_the_configuration_file` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 8.2.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_the_configuration_file (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $keystore_location = dig($facts['db2_instances'][$instance], 'keystore_location')

    if $keystore_location {
      db2_secured_setup { "secure_the_configuration_file validation on ${title}":
        ensure => 'present',
      }
      -> validation { "external keymanager configuration file should be SECURED on ${instance}":
        check           => "stat -c %a ${keystore_location}",
        path            => '/bin',
        expected_output => /600/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "external keymanager configuration file is NOT SECURED on ${instance}",
      }
    } else {
      warning 'Keystore location not configured'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
