#
# db2_secured::validators::secure_the_database_container_directory
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A DB2 database container is the physical storage of the data. 
# 
# 
# ## Rationale
# 
# The containers are needed in order for the database to operate properly. The loss of the containers can cause down time. Also, allowing excessive access to the containers may help an attacker to gain access to their contents. Therefore, secure the location(s) of the containers by restricting the access and ownership. Allow only the instance owner to have access to the tablespace containers.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_the_database_container_directory: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_the_database_container_directory` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 2.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_the_database_container_directory (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = $title.split('/')
  $inst     = $elements[0]
  $db       = $elements[1]

  if $facts['db2_instances'] {
    $dftdbpath = $facts['db2_instances'][$inst]['dftdbpath']

    db2_secured_setup { "secure_the_database_container_directory validation on ${title}":
      ensure => 'present',
    }
    -> validation { "database container directories should be SECURED on ${title}":
      check           => "find ${dftdbpath}/${inst}/NODE*/${db} -type d -not -perm 711; find ${dftdbpath}/${inst}/NODE*/${db} -type f -not -perm 600",
      path            => '/bin',
      expected_output => /^$/,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "database container directories are NOT SECURED on ${title}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
