#
# db2_secured::validators::secure_the_permission_of_the_sslconfig_ini_file
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `SSLconfig.ini` file contains the SSL configuration parameters for the DB2 instance, including the password for KeyStore.
# 
# 
# ## Rationale
# 
# Recommended value is full access to DB2 administrators only, read and write access only to members of the SYSADM group, and no access to other users. This will ensure that the parameter file is protected.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::secure_the_permission_of_the_sslconfig_ini_file: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `secure_the_permission_of_the_sslconfig_ini_file` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.7
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::secure_the_permission_of_the_sslconfig_ini_file (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']
    $file = "${home}/sqllib/cfg/SSLconfig.ini"

    db2_secured_setup { "secure_the_permission_of_the_sslconfig_ini_file validation on ${title}":
      ensure => 'present',
    }
    -> validation { "the permission of the SSLconfig.ini file should be SECURED on ${instance}":
      check           => "[ -r ${file} ] && stat -c %a ${file} || echo 760",
      path            => "/bin",
      environment     => "DB2INSTANCE=${instance}",
      expected_output => /(?-mix:^760$)/,
      user            => $instance,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "the permission of the SSLconfig.ini file is NOT SECURED on ${instance}",
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
