#
# db2_secured::validators::set_administrative_notification_level
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `notifylevel` parameter specifies the type of administration notification messages that are written to the administration notification log. It is recommended that this parameter be set greater than or equal to 3. A setting of 3, which includes settings 1 & 2, will log all fatal errors, failing services, system integrity, as well as system health.
# 
# 
# ## Rationale
# 
# The system should be monitoring all Health Monitor alarms, warnings, and attentions. This may give an indication of any malicious usage on the DB2 instance.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_administrative_notification_level: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_administrative_notification_level` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.12
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.9
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_administrative_notification_level (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $notifylevel = dig($facts['db2_instances'][$instance], 'notifylevel')

    if $notifylevel {
      db2_secured_setup { "set_administrative_notification_level validation on ${title}":
        ensure => 'present',
      }
      -> validation { "administrative notification level should be SET CORRECTLY on ${instance}":
        check           => "echo ${notifylevel}",
        path            => '/bin',
        expected_output => /3/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "administrative notification level is NOT SET CORRECTLY on ${instance}",
      }
    } else {
      warning "administrative notification level (notifylevel) not set on ${instance}"
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
