#
# db2_secured::validators::set_archive_log_failover_retry_limit
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `numarchretry` parameter determines how many times a database will try to archive the log file to the primary or the secondary archive destination before trying the failover directory. It is recommended that this parameter be set to 5.
# 
# 
# ## Rationale
# 
# Establishing a failover retry time limit will ensure that the database will always have a means to recover from an abnormal termination. This parameter should not be set to 0.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_archive_log_failover_retry_limit: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_archive_log_failover_retry_limit` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.22
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.11
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_archive_log_failover_retry_limit (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  if $facts['db2_databases'] {
    $numarchretry = dig($facts['db2_databases'], $title, 'numarchretry')

    if $numarchretry {
      db2_secured_setup { "set_archive_log_failover_retry_limit validation on ${title}":
        ensure => 'present',
      }
      -> validation { "archive log failover retry limit should be SET CORRECTLY on ${title}":
        check           => "echo ${numarchretry}",
        path            => '/bin',
        expected_output => /5/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "archive log failover retry limit is NOT SET CORRECTLY on ${title}",
      }
    } else {
      warning "archive log failover retry limit (numarchretry) not set on ${title}"
    }
  } else {
    warning "Skipping this validator until 'db2_databases' fact is filled"
  }
}
