#
# db2_secured::validators::set_diagnostic_logging_to_capture_errors_and_warnings
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `diaglevel` parameter specifies the type of diagnostic errors that will be recorded in the `db2diag.log` file. It is recommended that the `diaglevel` parameter be set to at least 3.
# 
# 
# ## Rationale
# 
# The recommended `diaglevel` setting is 3, but any value greater than 3 is also acceptable. A value of at least 3 will allow the DB2 instance to capture all errors and warnings that occur on the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_diagnostic_logging_to_capture_errors_and_warnings: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_diagnostic_logging_to_capture_errors_and_warnings` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.6
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_diagnostic_logging_to_capture_errors_and_warnings (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $diaglevel = dig($facts['db2_instances'][$instance], 'diaglevel')

    if $diaglevel {
      db2_secured_setup { "set_diagnostic_logging_to_capture_errors_and_warnings validation on ${title}":
        ensure => 'present',
      }
      -> validation { "diagnostic logging to capture errors and warnings should be SET CORRECTLY on ${instance}":
        check           => "echo ${diaglevel}",
        path            => '/bin',
        expected_output => /3/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "diagnostic logging to capture errors and warnings is NOT SET CORRECTLY on ${instance}",
      }
    } else {
      warning "diagnostic logging to capture errors and warnings (diaglevel) not set on ${instance}"
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
