#
# db2_secured::validators::set_failed_archive_retry_delay
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `archretrydelay` parameter specifies the number of seconds the DB2 service will wait before it reattempts to archive log files after a failure. It is recommended that this parameter be set anywhere in the range of 10-30. You do not want the delay to be so short that the database ends up in a denial of service scenario, but you don't want the delay to be too long if an outside attack happens at the same time.
# 
# 
# ## Rationale
# 
# Ensure that the value is non-zero, otherwise archive logging will not retry after the first failure. A denial of service attack can render the database without an archive log if this setting is not set. An archive log will ensure that all transactions can safely be restored or logged for auditing.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_failed_archive_retry_delay: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_failed_archive_retry_delay` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.14
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_failed_archive_retry_delay (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  if $facts['db2_databases'] {
    $archretrydelay = dig($facts['db2_databases'], $title, 'archretrydelay')

    if $archretrydelay {
      db2_secured_setup { "set_failed_archive_retry_delay validation on ${title}":
        ensure => 'present',
      }
      # lint:ignore:manifest_whitespace_closing_bracket_after
      -> validation { "failed archive retry delay should be SET CORRECTLY on ${title}":
        check           => "echo ${archretrydelay}",
        path            => '/bin',
        expected_output => /([12][0-9]|30)/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "failed archive retry delay is NOT SET CORRECTLY on ${title}",
      }
      # lint:endignore
    } else {
      warning "failed archive retry delay (archretrydelay) not set on ${title}"
    }
  } else {
    warning "Skipping this validator until 'db2_databases' fact is filled"
  }
}
