#
# db2_secured::validators::set_maximum_connection_limits
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `max_connections` parameter indicates the maximum number of client connections allowed per database partition. It is recommended that this parameter be set equal to the `max_coordagents` parameter. The `max_coordagents` parameter equals the maximum number of agents needed to perform connections to the database or attachments to the instance.
# NOTE: Ensure that dependent parameters, such as maxappls, are set less than the `max_coordagents` parameter. This would ensure that the lock limit isn't reached, which would result in lock escalation issues.
# 
# 
# ## Rationale
# 
# By default, DB2 allows an unlimited number of users to access the DB2 instance. In addition to giving access to the DB2 instance to authorized users only, it is recommended to set a limit to the number of users allowed to access a DB2 instance. This helps prevent denial of service conditions should an authorized process malfunction and attempt a large number of simultaneous connections.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_maximum_connection_limits: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_maximum_connection_limits` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.11
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_maximum_connection_limits (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  db2_secured_setup { "set_maximum_connection_limits validation on ${title}":
    ensure => 'present',
  }

  if $facts['db2_instances'] {
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '10' {
      $max_coordagents = dig($facts['db2_instances'][$instance], 'max_coordagents')
      $max_connections = dig($facts['db2_instances'][$instance], 'max_connections')

      if $facts['db2_databases'] {
        $maxappls = dig($facts['db2_databases'], $title, 'maxappls')

        if $max_coordagents and $max_connections and $maxappls {
          $max_conns = case String($max_connections) {
            'AUTOMATIC(MAX_COORDAGENTS)': {
              case String($max_coordagents) {
                /AUTOMATIC\((\d+)\)/: { $1 }
                /^(\d+)$/:            { $1 }
                default:              { fail "unable to parse max_coordagents (${max_coordagents})" }
              }
            }
            '-1': {
              case String($max_coordagents) {
                /AUTOMATIC\((\d+)\)/: { $1 }
                /^(\d+)$/:            { $1 }
                default:              { fail "unable to parse max_coordagents (${max_coordagents})" }
              }
            }
            default: {
              $max_connections
            }
          }
          $max_apps = case String($maxappls) {
            /^AUTOMATIC\((\d+)\)$/: { $1 }
            /(\d+)/:                { $1 }
            default:                { fail "unable to parse maxappls (${maxappls})" }
          }
          validation { "maximum connection limits should be SET CORRECTLY on ${instance}":
            check           => "[ \"${max_apps}\" -le \"${max_conns}\" ] && echo \"OK,${maxappls},${max_coordagents},${max_connections}\" || echo \"NOT OK,${maxappls},${max_coordagents},${max_connections}\"",
            path            => '/bin',
            expected_output => /^OK,AUTOMATIC\(\d+\),AUTOMATIC\(\d+\),AUTOMATIC\(MAX_COORDAGENTS\)$/,
            report_as       => $report_as,
            skip            => $skip,
            control         => easy_type::current_control(),
            fail_message    => "maximum connection limits is NOT SET CORRECTLY on ${instance}",
            require         => Db2_secured_setup["set_maximum_connection_limits validation on ${title}"],
          }
        } else {
          warning "maximum connection limits (max_connections) or maximum number of coordinating agents (max_coordagents) or max number of active applications (maxappls) not set on ${instance}"
        }
      } else {
        warning "Skipping this validator until 'db2_databases' fact is filled"
      }
    } else {
      warning 'validator only supported on db2 version 10'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
