#
# db2_secured::validators::set_maximum_number_of_applications
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `maxappls` parameter specifies the maximum number of concurrent applications that can be connected (both local and remote) to a database. In an instance with a single database, it is recommended that this value be set to `AUTOMATIC`. While this indicates that any number of connections should be allowed, an upper limit of `max_connections` database manager configuration parameter is still enforced. If there are multiple databases within the instance, then the sum of `maxappls` for each database should be less than or equal to `max_connections`.
# When `AUTOMATIC` is used, `maxappls` can also have a parameter. The value is not used to determine the maximum number of connections, but rather for dependent parameters, such as pckcachesz and catalog_cachesz that can derive their value from `maxappls`. In such a case the value specified with `AUTOMATIC` should represent the expected number of connections.
# 
# 
# ## Rationale
# 
# By default, Db2 allows an unlimited number of users to access the Db2 instance. In addition to giving access to the Db2 instance to authorized users only, it is recommended to set a limit to the number of users allowed to access a Db2 instance. This helps prevent denial of service conditions should an authorized process malfunction and attempt many simultaneous connections.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_maximum_number_of_applications: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_maximum_number_of_applications` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.12
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_maximum_number_of_applications (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '11' {
      $max_coordagents = dig($facts['db2_instances'][$instance], 'max_coordagents')
      $max_connections = dig($facts['db2_instances'][$instance], 'max_connections')

      if $max_coordagents and $max_connections {
        $max_conns = case String($max_connections) {
          'AUTOMATIC(MAX_COORDAGENTS)': {
            case String($max_coordagents) {
              /AUTOMATIC\((\d+)\)/: { $1 }
              /^(\d+)$/:            { $1 }
              default:              { fail "unable to parse max_coordagents (${max_coordagents})" }
            }
          }
          '-1': {
            case String($max_coordagents) {
              /AUTOMATIC\((\d+)\)/: { $1 }
              /^(\d+)$/:            { $1 }
              default:              { fail "unable to parse max_coordagents (${max_coordagents})" }
            }
          }
          default: {
            $max_connections
          }
        }

        if $facts['db2_databases'] {
          $maxappls = dig($facts['db2_databases'], $title, 'maxappls')

          if $maxappls {
            $max_apps = case String($maxappls) {
              /^AUTOMATIC\((\d+)\)$/: { $1 }
              /(\d+)/:                { $1 }
              default:                { fail "unable to parse maxappls (${maxappls})" }
            }
            db2_secured_setup { "set_maximum_number_of_applications validation on ${title}":
              ensure => 'present',
            }

            $num_dbs = $facts['db2_databases'].keys.grep($instance).length
            if Integer($num_dbs) > 1 {
              $all_conns = $facts['db2_databases'].reduce(0) |$memo, $value| {
                $conns = case String($value[1]['maxappls']) {
                  /^AUTOMATIC\((\d+)\)$/: { $1 }
                  /^(\d+)$/:              { $1 }
                }
                $memo + Integer($conns)
              }
              validation { "maximum number of applications should be SET CORRECTLY on ${title}":
                check           => "[ \"${all_conns}\" -le \"${max_conns}\" ] && echo \"OK\" || echo \"NOT OK\"",
                path            => '/bin',
                expected_output => /^OK$/,
                report_as       => $report_as,
                skip            => $skip,
                control         => easy_type::current_control(),
                fail_message    => "maximum number of applications is NOT SET CORRECTLY on ${title}",
                require         => Db2_secured_setup["set_maximum_number_of_applications validation on ${title}"],
              }
            } else {
              validation { "maximum number of applications should be SET CORRECTLY on ${title}":
                check           => "echo \"${maxappls}\"",
                path            => '/bin',
                expected_output => /AUTOMATIC/,
                report_as       => $report_as,
                skip            => $skip,
                control         => easy_type::current_control(),
                fail_message    => "maximum number of applications is NOT SET CORRECTLY on ${title}",
                require         => Db2_secured_setup["set_maximum_number_of_applications validation on ${title}"],
              }
            }
          } else {
            warning "maximum number of applications (maxappls) not set on ${title}"
          }
        } else {
          warning "Skipping this validator until 'db2_databases' fact is filled"
        }
      } else {
        warning "maximum connection limits (max_connections) or maximum number of coordinating agents (max_coordagents) not set on ${instance}"
      }
    } else {
      warning 'validator only supported on db2 version 11'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
