#
# db2_secured::validators::set_umask_value_in_the_db2_instance_owners_profile
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The Db2 instance owner’s .profile file in Linux sets the environment variables and the settings for the user. This file is specific to the Korn shell and BASH shell, and other shells may have a different file.
# 
# 
# ## Rationale
# 
# The umask value should be set to `022` for the owner of the Db2 software at all times to ensure files are not created with unnecessary privileges.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_umask_value_in_the_db2_instance_owners_profile: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_umask_value_in_the_db2_instance_owners_profile` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.3.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_umask_value_in_the_db2_instance_owners_profile (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '11' {
      db2_secured_setup { "set_umask_value_in_the_db2_instance_owners_profile validation on ${title}":
        ensure => 'present',
      }
      # lint:ignore:leading_zero
      -> validation { "umask value for DB2 admin user should be SET CORRECTLY on ${instance}":
        check           => "grep \"umask.*022\" $(cat /etc/passwd|grep ${instance}|awk -F: '{print $(NF-1)}')/.bash_profile $(cat /etc/passwd|grep ${instance}|awk -F: '{print $(NF-1)}')/.profile 2>/dev/null",
        path            => '/bin',
        expected_output => /: *umask *022/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        user            => $instance,
        fail_message    => "umask value for DB2 admin user is NOT SET CORRECTLY on ${instance}",
      }
      # lint:endignore
    } else {
      warning 'validator only supported on db2 version 11'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
