#
# db2_secured::validators::specify_secure_remote_shell_command
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `db2rshcmd` registry varible specifies the remote shell command to use when starting remote database partitions and with the db2_all script to run utilities and commands on all database partitions. It is recommended that a value be used which encrypts the data sent between partitions, such as ssh.
# 
# 
# ## Rationale
# 
# The traditional rsh command sends all its data, including passwords, in plaintext between partitions. An attacker who can read network traffic may have access to these passwords and other data. Specifying a remote shell command, such as ssh encrypts the data sent over the network.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::specify_secure_remote_shell_command: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `specify_secure_remote_shell_command` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::specify_secure_remote_shell_command (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '11' {
      db2_secured_setup { "specify_secure_remote_shell_command validation on ${title}":
        ensure => 'present',
      }
      $mod_pack = split($db2_version, '\.')[2]
      if Integer($mod_pack) >= 6 {
        validation { "secure remote shell command should be SET CORRECTLY on ${instance}":
          check           => 'db2set -all | grep DB2RSHCMD',
          path            => ['/bin', "${home}/sqllib/adm"],
          environment     => "DB2INSTANCE=${instance}",
          expected_output => /(?-mix:(^$|DB2RSHCMD=ssh$))/,
          report_as       => $report_as,
          skip            => $skip,
          control         => easy_type::current_control(),
          user            => $instance,
          fail_message    => "secure remote shell command is NOT SET CORRECTLY on ${instance}",
          require         => Db2_secured_setup["specify_secure_remote_shell_command validation on ${title}"],
        }
      } else {
        validation { "secure remote shell command should be SET CORRECTLY on ${instance}":
          check           => 'db2set -all | grep DB2RSHCMD',
          path            => ['/bin', "${home}/sqllib/adm"],
          environment     => "DB2INSTANCE=${instance}",
          expected_output => /(?-mix:(DB2RSHCMD=ssh$))/,
          report_as       => $report_as,
          skip            => $skip,
          control         => easy_type::current_control(),
          user            => $instance,
          fail_message    => "secure remote shell command is NOT SET CORRECTLY on ${instance}",
          require         => Db2_secured_setup["specify_secure_remote_shell_command validation on ${title}"],
        }
      }
    } else {
      warning 'validator only supported on db2 version 11'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
