#
# db2_secured::validators::ssl_service_name_ssl_svcename
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `ssl_svcename` configuration parameter defines the name or number of the port the database server listens for communications from remote client nodes using SSL protocol. The `ssl_svcename` and the svcename port numbers cannot be the same.
# On Linux operating systems, the `ssl_svcename` file is located in: /etc/services
# 
# 
# ## Rationale
# 
# The database requires a defined port to listen for incoming remote clients using the SSL protocol. The `ssl_svcename` configuration parameter defines the port for communicating with remote clients.
# Consider using a non-default port to help protect the database from attacks directed to a default port.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::ssl_service_name_ssl_svcename: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `ssl_service_name_ssl_svcename` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.2.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::ssl_service_name_ssl_svcename (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  if $facts['db2_instances'] {
    $db2_version = dig($facts['db2_instances'][$inst], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '10' {
      $query    = @(QUERY)
          SELECT NAME
               , VALUE
            FROM SYSIBMADM.DBMCFG
           WHERE NAME = 'ssl_svcename'
             AND VALUE <> 50000
             AND VALUE IS NOT NULL
        |-QUERY

      db2_secured_setup { "ssl_service_name_ssl_svcename validation on ${title}":
        ensure => 'present',
      }
      -> db2_validation { "SSL service name - ssl_svcename should be SET CORRECTLY on ${title}":
        check                   => $query,
        instance_name           => $inst,
        database_name           => $db,
        expected_number_of_rows => 1,
        report_as               => $report_as,
        skip                    => $skip,
        control                 => easy_type::current_control(),
        fail_message            => "SSL service name - ssl_svcename is NOT SET CORRECTLY on ${title}",
      }
    } else {
      warning 'validator only supported on db2 version 10'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
