#
# db2_secured::validators::tcp_ip_service_name_svcename
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `svcename` parameter reserves the port number (or name, on Linux hosts) for listening to incoming communications from a Data Server Runtime Client. Both the database server port number or name and the TCP/IP service name must be defined on the database client.
# 
# 
# ## Rationale
# 
# When the database server is started, a port number or name is required to listen for incoming connection requests. The `svcename` parameter defines the port number or name for incoming connection requests. On Linux systems, the services file is found at: /etc/services
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::tcp_ip_service_name_svcename: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `tcp_ip_service_name_svcename` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.2.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::tcp_ip_service_name_svcename (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $elements = split($title, '/')
  $inst     = $elements[0]
  $db       = $elements[1]
  if $facts['db2_instances'] {
    $db2_version = dig($facts['db2_instances'][$inst], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '10' {
      $query    = @(QUERY)
          SELECT NAME
               , VALUE
            FROM SYSIBMADM.DBMCFG
           WHERE NAME = 'svcename'
             AND VALUE <> 50000
             AND VALUE IS NOT NULL
        |-QUERY

      db2_secured_setup { "tcp_ip_service_name_svcename validation on ${title}":
        ensure => 'present',
      }
      -> db2_validation { "TCP/IP service name - svcename should be SET CORRECTLY on ${title}":
        check                   => $query,
        instance_name           => $inst,
        database_name           => $db,
        expected_number_of_rows => 1,
        report_as               => $report_as,
        skip                    => $skip,
        control                 => easy_type::current_control(),
        fail_message            => "TCP/IP service name - svcename is NOT SET CORRECTLY on ${title}",
      }
    } else {
      warning 'validator only supported on db2 version 10'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
