#
# db2_secured::validators::turn_off_remote_command_legacy_mode
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `DB2RCMD_LEGACY_MODE` registry variable determines whether the Db2 Remote Command Service runs with enhanced security or not. It is recommended that legacy mode not be enabled.
# This registry variable only applies to Db2 Servers running on Windows.
# 
# 
# ## Rationale
# 
# Legacy mode requires the Db2 service account to have privileges to impersonate the client account.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::turn_off_remote_command_legacy_mode: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `turn_off_remote_command_legacy_mode` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::turn_off_remote_command_legacy_mode (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '11' {
      db2_secured_setup { "turn_off_remote_command_legacy_mode validation on ${title}":
        ensure => 'present',
      }
      -> validation { "remote command legacy mode should be TURNED OFF on ${instance}":
        check           => 'db2set -all | grep DB2RCMD_LEGACY_MODE',
        path            => ['/bin', "${home}/sqllib/adm"],
        environment     => "DB2INSTANCE=${instance}",
        expected_output => /(?-mix:(^$|DB2RCMD_LEGACY_MODE=OFF$))/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        user            => $instance,
        fail_message    => "remote command legacy mode is NOT TURNED OFF on ${instance}",
      }
    } else {
      warning 'validator only supported on db2 version 11'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
