#
# db2_secured::validators::use_ip_address_rather_than_hostname
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Use an IP address rather than a hostname to connect to the host of the DB2 instance.
# 
# 
# ## Rationale
# 
# Using a hostname to connect to a DB2 instance can display useful information about the host to an attacker. For example, hostnames for DB2 instances often contain the DB2 version number, host type, or operating system type
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::use_ip_address_rather_than_hostname: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `use_ip_address_rather_than_hostname` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 1.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::use_ip_address_rather_than_hostname (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '10' {
      db2_secured_setup { "use_ip_address_rather_than_hostname validation on ${title}":
        ensure => 'present',
      }
      -> validation { "IP address should be USED on ${instance}":
          check           => "db2 list node directory show detail | grep Hostname | awk '{print \$NF}'",
          path            => ['/bin', "${home}/sqllib/bin"],
          environment     => "DB2INSTANCE=${instance}",
          expected_output => /(?-mix:(^$|^((?:(?:^|\.)(?:\d|[1-9]\d|1\d{2}|2[0-4]\d|25[0-5])){4})$))/,
          report_as       => $report_as,
          skip            => $skip,
          control         => easy_type::current_control(),
          user            => $instance,
          fail_message    => "IP address is NOT USED on ${instance}",
        }
    } else {
      warning 'validator only supported on db2 version 10'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
