#
# db2_secured::validators::use_non_default_account_names
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The DB2 service is installed with default accounts with well-known names such as db2admin, db2inst1, dasusr1, or db2fenc1. It is recommended that the use of these account names be avoided. The default accounts may be renamed and then used.
# 
# 
# ## Rationale
# 
# The use of default account names may increase the DB2 service's susceptibility to unauthorized access by an attacker.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::use_non_default_account_names: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `use_non_default_account_names` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 1.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::use_non_default_account_names (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']
    $db2_version = dig($facts['db2_instances'][$instance], 'version')

    if $db2_version and split($db2_version, '\.')[0] == '10' {
      db2_secured_setup { "use_non_default_account_names validation on ${title}":
        ensure => 'present',
      }
      -> validation { "IP address should be USED on ${instance}":
        check           => "grep -P \"DB2_${instance}\t\" /etc/services | awk -F'[\t/]' '{print \$2}' | grep -v 50000",
        path            => ['/bin', "${home}/sqllib/bin"],
        expected_output => /^\d+$/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        user            => $instance,
        fail_message    => "IP address is NOT USED on ${instance}",
      }
    } else {
      warning 'validator only supported on db2 version 10'
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
